@@ -1,20 +1,9 @@
 /*
-  Copyright 2010 BetterInbox <contact@betterinbox.com>
-      Author: Christophe Laveault <christophe@betterinbox.com>
-              Gregory Schlomoff <gregory.schlomoff@gmail.com>
+  SPDX-FileCopyrightText: 2010 BetterInbox <contact@betterinbox.com>
+  SPDX-FileContributor: Christophe Laveault <christophe@betterinbox.com>
+  SPDX-FileContributor: Gregory Schlomoff <gregory.schlomoff@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "session.h"
@@ -42,15 +31,8 @@ SessionPrivate::SessionPrivate(Session *session)
     : QObject(session)
     , q(session)
     , m_state(Session::Disconnected)
-    , m_thread(nullptr)
     , m_socketTimerInterval(60000)
-    , m_startLoop(nullptr)
     , m_sslVersion(QSsl::UnknownProtocol)
-    , m_jobRunning(false)
-    , m_currentJob(nullptr)
-    , m_ehloRejected(false)
-    , m_size(0)
-    , m_allowsTls(false)
 {
     qRegisterMetaType<QSsl::SslProtocol>();
     qRegisterMetaType<KSslErrorUiData>();
